@@ -1,4 +1,4 @@
-// Copyright © 2016-2021 Thomas Nagler and Thibault Vatter
+// Copyright © 2016-2022 Thomas Nagler and Thibault Vatter
 //
 // This file is part of the vinecopulib library and licensed under the terms of
 // the MIT license. For a copy, see the LICENSE file in the root directory of
@@ -35,7 +35,7 @@ Eigen::VectorXd
 binaryExpr_or_nan(const Eigen::MatrixXd& u, const T& func)
 {
   auto func_or_nan = [&func](const double& u1, const double& u2) {
-    if ((boost::math::isnan)(u1) || (boost::math::isnan)(u2)) {
+    if ((boost::math::isnan)(u1) | (boost::math::isnan)(u2)) {
       return std::numeric_limits<double>::quiet_NaN();
     } else {
       return func(u1, u2);
